recsyslearn package
===================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   recsyslearn.accuracy
   recsyslearn.beyond_accuracy
   recsyslearn.dataset
   recsyslearn.errors
   recsyslearn.fairness

Submodules
----------

recsyslearn.utils module
------------------------

.. automodule:: recsyslearn.utils
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: recsyslearn
   :members:
   :undoc-members:
   :show-inheritance:
